@@ -6,12 +6,12 @@ use Carp;
 
 require Exporter;
 
-our $VERSION = '0.20_02';
+our $VERSION = '0.20_03';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION; # so "use Module 0.002" won't warn on underscore
 
 our @_functions = qw(
-a64l abort abs access acos acosh alarm asin asinh atan2 atan atanh atof atoi
+a64l abort abs access acos acosh alarm asin asinh atan atan2 atanh atof atoi
 basename cabs cacos cacosh carg casin casinh catan catanh catclose catgets
 catopen cbrt ccos ccosh ceil cexp chdir chmod chown cimag clock
 clock_getcpuclockid clock_getres clock_gettime clock_nanosleep clock_settime
@@ -22,17 +22,18 @@ fdopendir fegetround fesetround ffs floor fma fmax fmin fmod fnmatch
 fpclassify fstatat fsync futimens getdate getdate_err getegid geteuid getgid
 gethostid gethostname getitimer getpriority getsid getuid getutxent getutxid
 getutxline hypot ilogb isalnum isalpha isascii isatty isblank iscntrl isdigit
-isfinite isgraph isinf islower isnan isnormal isprint ispunct isspace isupper
-isxdigit j0 j1 jn jrand48 killpg l64a ldexp lgamma link linkat log log1p log2
-logb lrand48 lround lstat mkdir mkdirat mkdtemp mkfifo mkfifoat mknod mknodat
-mkstemp mrand48 nanosleep nearbyint nextafter nrand48 openat openat2 open
-pread preadv ptsname pwrite pwritev random read readlink readlinkat realpath
-readv remainder remove rename renameat rmdir round scalbn seed48 setegid
+isfinite isgraph isgreaterequal isinf isless islessequal islessgreater islower
+isnan isnormal isprint ispunct isspace isunordered isupper isxdigit j0 j1 jn
+jrand48 killpg l64a ldexp lgamma link linkat log log1p log2 logb lrand48
+lround lstat mkdir mkdirat mkdtemp mkfifo mkfifoat mknod mknodat mkstemp
+mrand48 nanosleep nearbyint nextafter nice nrand48 open openat openat2 pread
+preadv ptsname pwrite pwritev random read readlink readlinkat readv realpath
+remainder remove remquo rename renameat rmdir round scalbn seed48 setegid
 seteuid setgid setitimer setpriority setregid setreuid setsid setuid setutxent
 sighold sigignore signbit sigpause sigrelse sin sinh srand48 srandom stat
 strptime symlink symlinkat sync tan tanh tgamma timer_create timer_delete
-timer_getoverrun timer_gettime timer_settime truncate trunc ttyname unlinkat
-unlink utimensat write writev y0 y1 yn
+timer_getoverrun timer_gettime timer_settime trunc truncate ttyname unlink
+unlinkat utimensat write writev y0 y1 yn
 );
 
 our @_constants = qw(
@@ -45,20 +46,22 @@ CLOCK_REALTIME_PRECISE CLOCK_SOFTTIME CLOCK_THREAD_CPUTIME_ID CLOCK_UPTIME
 CLOCK_UPTIME_FAST CLOCK_UPTIME_PRECISE _CS_GNU_LIBC_VERSION
 _CS_GNU_LIBPTHREAD_VERSION _CS_PATH DEAD_PROCESS F_DUPFD F_DUPFD_CLOEXEC
 F_GETFD F_SETFD F_GETFL F_SETFL F_GETLK F_SETLK F_SETLKW F_GETOWN F_SETOWN
-F_RDLCK F_UNLCK F_WRLCK FD_CLOEXEC FNM_CASEFOLD FNM_FILE_NAME FNM_LEADING_DIR
-FNM_NOESCAPE FNM_NOMATCH FNM_PATHNAME FNM_PERIOD FP_INFINITE FP_NAN FP_NORMAL
-FP_SUBNORMAL FP_ZERO INIT_PROCESS ITIMER_PROF ITIMER_REAL ITIMER_VIRTUAL
-LOGIN_PROCESS NEW_TIME O_ACCMODE O_APPEND O_CLOEXEC O_CREAT O_DIRECTORY
-O_DSYNC O_EXEC O_NOCTTY O_NOFOLLOW O_NONBLOCK O_RDONLY O_RDWR O_RSYNC O_SEARCH
-O_SYNC O_TMPFILE O_TRUNC O_TTY_INIT O_WRONLY OLD_TIME POSIX_FADV_NORMAL
+F_RDLCK F_UNLCK F_WRLCK FD_CLOEXEC FE_TONEAREST FE_TOWARDZERO FE_UPWARD
+FE_DOWNWARD FE_DIVBYZERO FE_INEXACT FE_INVALID FE_OVERFLOW FE_UNDERFLOW
+FE_ALL_EXCEPT FNM_CASEFOLD FNM_FILE_NAME FNM_LEADING_DIR FNM_NOESCAPE
+FNM_NOMATCH FNM_PATHNAME FNM_PERIOD FP_INFINITE FP_NAN FP_NORMAL FP_SUBNORMAL
+FP_ZERO INIT_PROCESS ITIMER_PROF ITIMER_REAL ITIMER_VIRTUAL LOGIN_PROCESS
+NEW_TIME O_ACCMODE O_APPEND O_CLOEXEC O_CREAT O_DIRECTORY O_DSYNC O_EXEC
+O_NOCTTY O_NOFOLLOW O_NONBLOCK O_RDONLY O_RDWR O_RSYNC O_SEARCH O_SYNC
+O_TMPFILE O_TRUNC O_TTY_INIT O_WRONLY OLD_TIME POSIX_FADV_NORMAL
 POSIX_FADV_SEQUENTIAL POSIX_FADV_RANDOM POSIX_FADV_NOREUSE POSIX_FADV_WILLNEED
-POSIX_FADV_DONTNEED RESOLVE_BENEATH RESOLVE_IN_ROOT RESOLVE_NO_MAGICLINKS
-RESOLVE_NO_SYMLINKS RESOLVE_NO_XDEV RESOLVE_CACHED RTLD_GLOBAL RTLD_LAZY
-RTLD_LOCAL RTLD_NOW RUN_LVL S_IFMT S_IFBLK S_IFCHR S_IFIFO S_IFREG S_IFDIR
-S_IFLNK S_IFSOCK S_ISUID S_ISGID S_IRWXU S_IRUSR S_IWUSR S_IXUSR S_IRWXG
-S_IRGRP S_IWGRP S_IXGRP S_IRWXO S_IROTH S_IWOTH S_IXOTH S_ISVTX SEEK_SET
-SEEK_CUR SEEK_END TIMER_ABSTIME USER_PROCESS UTIME_NOW UTIME_OMIT F_OK R_OK
-W_OK X_OK
+POSIX_FADV_DONTNEED PRIO_PROCESS PRIO_PGRP PRIO_USER RESOLVE_BENEATH
+RESOLVE_IN_ROOT RESOLVE_NO_MAGICLINKS RESOLVE_NO_SYMLINKS RESOLVE_NO_XDEV
+RESOLVE_CACHED RTLD_GLOBAL RTLD_LAZY RTLD_LOCAL RTLD_NOW RUN_LVL S_IFMT
+S_IFBLK S_IFCHR S_IFIFO S_IFREG S_IFDIR S_IFLNK S_IFSOCK S_ISUID S_ISGID
+S_IRWXU S_IRUSR S_IWUSR S_IXUSR S_IRWXG S_IRGRP S_IWGRP S_IXGRP S_IRWXO
+S_IROTH S_IWOTH S_IXOTH S_ISVTX SEEK_SET SEEK_CUR SEEK_END TIMER_ABSTIME
+USER_PROCESS UTIME_NOW UTIME_OMIT F_OK R_OK W_OK X_OK
 );
 
 our @ISA = qw(Exporter);
